==> rescript-9.1.1-dev.2.tgz: package/lib/ocaml/js_cast.mli <==
(* Copyright (C) 2015-2016 Bloomberg Finance L.P.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * In addition to the permissions granted to you by the LGPL, you may combine
 * or link a "work that uses the Library" with a publicly distributed version
 * of this file to produce a combined library or application, then distribute
 * that combined work under the terms of your choosing, with no requirement
 * to comply with the obligations normally placed on you by section 4 of the
 * LGPL version 3 (or the corresponding section of a later version of the LGPL
 * should you choose to use a later version).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *)

(** Safe cast between OCaml values which share the same 
    runtime representation


    Different OCaml types might share the same represention in the 
    ReScript runtime; while this is a compiler internal knowledge,
    applications might benefit from having a safe and zero cost 
    conversion between those types. 

    This modules acts as the {b single place} for such conversion. 

    If for any reason, the runtime representation changes, those function 
    will be modified accordingly. *)

external intOfBool : bool -> int = "%identity"  
(** [intOfBool b] returns [1] for when [b] is [true] and [0] when [b] is 
    [false] *)

external floatOfInt : int -> float = "%identity"  
(** [floatOfInt i] returns the float value of [i] *)

==> rescript-9.1.4.tgz: package/lib/ocaml/js_cast.mli <==
(* Copyright (C) 2015-2016 Bloomberg Finance L.P.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * In addition to the permissions granted to you by the LGPL, you may combine
 * or link a "work that uses the Library" with a publicly distributed version
 * of this file to produce a combined library or application, then distribute
 * that combined work under the terms of your choosing, with no requirement
 * to comply with the obligations normally placed on you by section 4 of the
 * LGPL version 3 (or the corresponding section of a later version of the LGPL
 * should you choose to use a later version).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *)

(**
  Safe cast between OCaml values which share the same
  runtime representation

  Different OCaml types might share the same represention in the
  ReScript runtime; while this is a compiler internal knowledge,
  applications might benefit from having a safe and zero cost
  conversion between those types.

  This modules acts as the **single place** for such conversion.

  If for any reason, the runtime representation changes, those function
  will be modified accordingly.
*)

external intOfBool : bool -> int = "%identity"
(** `intOfBool b` returns `1` for when `b` is `true` and `0` when `b` is
    `false` *)

external floatOfInt : int -> float = "%identity"
(** `floatOfInt i` returns the float value of `i` *)
